# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings
import django.core.validators
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=32, verbose_name='Nom de l\u2019\xe9v\xe8nement')),
                ('description', models.TextField(blank=True)),
                ('start_date', models.DateTimeField(verbose_name='Date et heure de d\xe9but')),
                ('end_date', models.DateTimeField(verbose_name='Date et heure de fin')),
                ('limit_godson', models.PositiveIntegerField(default=0, verbose_name='Nombre de parrainage authoris\xe9 par personne (0 = pas de parrainage)')),
                ('managers', models.ManyToManyField(related_name='organised_events', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['start_date'],
            },
        ),
        migrations.CreateModel(
            name='Registration',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('uuid', models.CharField(max_length=64)),
                ('payee', models.CharField(default=None, max_length=64, null=True)),
                ('paid', models.BooleanField(default=False)),
                ('comments', models.TextField(default='', blank=True)),
                ('purchase_date', models.DateTimeField(auto_now_add=True)),
                ('owner', models.ForeignKey(related_name='registrations', to=settings.AUTH_USER_MODEL, on_delete=django.db.models.deletion.PROTECT)),
            ],
        ),
        migrations.CreateModel(
            name='Ticket',
            fields=[
                ('primarykey', models.AutoField(serialize=False, primary_key=True)),
                ('id', models.IntegerField(editable=False)),
                ('name', models.CharField(max_length=32)),
                ('short_notes', models.CharField(max_length=256, verbose_name='Remarques (courtes, liste des billets)', blank=True)),
                ('long_notes', models.TextField(default='', verbose_name='Remarques (longues, page de confirmation)', blank=True)),
                ('price', models.DecimalField(verbose_name='Prix', max_digits=6, decimal_places=2, validators=[django.core.validators.MinValueValidator(0.01, message='Le prix d\u2019un billet doit \xeatre positif.')])),
                ('limit', models.PositiveIntegerField(default=0, verbose_name='Nombre de place disponible (0 = illimit\xe9)')),
                ('allowed_external', models.BooleanField(default=False)),
                ('required_school', models.IntegerField(default=1, verbose_name='Billet accessible aux', choices=[(1, '\xc9tudiants INP (toute \xe9cole)'), (2, '\xc9tudiants N7'), (3, '\xc9tudiants ENSAT'), (4, '\xc9tudiants A7')])),
                ('required_ae', models.BooleanField(default=True, verbose_name='Ce billet est r\xe9serv\xe9 aux adh\xe9rents de l\u2019AE')),
                ('allowed_godson', models.BooleanField(default=False, verbose_name='Ce billet est accessible aux personnes parrain\xe9es')),
                ('design', models.FileField(upload_to='billetterie', verbose_name='Template du billet')),
                ('event', models.ForeignKey(related_name='tickets', to='guichet.Event', on_delete=django.db.models.deletion.CASCADE)),
            ],
            options={
                'ordering': ['id'],
            },
        ),
        migrations.AddField(
            model_name='registration',
            name='ticket',
            field=models.ForeignKey(related_name='registrations', to='guichet.Ticket', on_delete=django.db.models.deletion.CASCADE),
        ),
        migrations.AlterUniqueTogether(
            name='ticket',
            unique_together=set([('event', 'id')]),
        ),
    ]
